==> hyades.source_3.0.0_20040621_1225.zip: org/eclipse/hyades/test/ui/datapool/internal/action/PasteAction.java <==
/*******************************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.datapool.internal.action;

import org.eclipse.hyades.test.ui.datapool.DatapoolPlugin;
import org.eclipse.hyades.test.ui.datapool.internal.control.DatapoolTable;
import org.eclipse.hyades.test.ui.datapool.internal.util.ContextIds;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.ui.actions.SelectionProviderAction;
import org.eclipse.ui.help.WorkbenchHelp;


/**
 * @author psun
 *
 */
public class PasteAction extends SelectionProviderAction {

	private DatapoolTable table;

	public PasteAction(ISelectionProvider viewer, DatapoolTable table)
	{
		super(viewer, DatapoolPlugin.getResourceString("PASTE_TEXT")); //$NON-NLS-1$
		setDescription(DatapoolPlugin.getResourceString("PASTE_LDESC")); //$NON-NLS-1$
		WorkbenchHelp.setHelp(this, DatapoolPlugin.getID() + ContextIds.PASTE_ACT);
		this.table = table;
	}

	public void run()
	{
		if (table != null)
			table.paste();
	}

	public void aboutToShow(boolean bShow)
	{
		setEnabled(bShow);
	}	
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/test/ui/datapool/internal/action/PasteAction.java <==
/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: PasteAction.java,v 1.5 2005/02/16 22:22:14 qiyanli Exp $
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.datapool.internal.action;

import org.eclipse.hyades.test.ui.datapool.DatapoolPlugin;
import org.eclipse.hyades.test.ui.datapool.internal.control.DatapoolTable;
import org.eclipse.hyades.test.ui.datapool.internal.util.ContextIds;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.ui.actions.SelectionProviderAction;
import org.eclipse.ui.help.WorkbenchHelp;
import org.eclipse.ui.texteditor.IWorkbenchActionDefinitionIds;


/**
 * @author psun
 *
 */
public class PasteAction extends SelectionProviderAction {

	private DatapoolTable table;

	public PasteAction(ISelectionProvider viewer, DatapoolTable table)
	{
		super(viewer, DatapoolPlugin.getResourceString("PASTE_TEXT")); //$NON-NLS-1$
		this.setId(this.getClass().getName());
		this.setActionDefinitionId(IWorkbenchActionDefinitionIds.PASTE);
		setDescription(DatapoolPlugin.getResourceString("PASTE_LDESC")); //$NON-NLS-1$
		WorkbenchHelp.setHelp(this, DatapoolPlugin.getID() + ContextIds.PASTE_ACT);
		this.table = table;
	}

	public void run()
	{
		if (table != null)
			table.paste();
	}

	public void aboutToShow(boolean bShow)
	{
		setEnabled(bShow);
	}	
}
